from enum import Enum
from typing import Optional
from pydantic import BaseModel


class ApiRequestPayload(BaseModel):
    recipient: dict
    messaging_type: str = "Response"
    message:Optional[str]



class SendingMessageFailedException(Exception):

    def __init__(self, code, *args: object) -> None:
        self.code = code
        super().__init__(*args)

    def __str__(self) -> str:
        return 'HTTP error code {code}\n{trace}'.format(code=self.code,
                                                        trace=super().__str__())


from typing import Dict, Optional
from requests import Response
from .execeptions import SendingMessageFailedException
from .types import ApiRequestPayload


class MessengerAPI:

    def __init__(self,  access_token: str, page_id: str, api_version: str = 'v16.0'):
        self.access_token = access_token
        self.base_url = f'https://graph.facebook.com/{api_version}/{page_id}'
        self.headers: Dict[str, str] = {
            'Content-Type': 'application/json',
        }

    def send_text_message(self, user_id: str, message):
        payload = ApiRequestPayload(
            recipient={"id": user_id}, message={"text": message})
        url = f"{self.base_url}/messages?access_token={self.access_token}"
        result = requests.post(url, headers=self.headers, data=payload.json())

        if result.status_code != 200:
            raise SendingMessageFailedException(result.status_code)
        return result

    def get_media(self, uri: str) -> Optional[Response]:
        response = requests.get(uri, stream=True)
        response.raise_for_status()
        return response


import os
from setuptools import find_packages, setup

with open('README.rst') as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name="messenger-business-api",
    version="1.0.2",
    author="Yuri Ramos Lima",
    author_email="yurilima93@hotmail.com",
    description="This repository is a wrapper for Meta messenger api for Messenger and Instagram",
    packages=find_packages(),
    include_package_data=True,
    long_description=README,
    install_requires=[ "pydantic", "requests"],
    license="MIT License",
    keywords=["python","Meta", "Facebook", "Instagram", "message", "chat-bot"],
   
)
